@@ -1,7 +1,7 @@
 package MooX::TypeTiny;
 use strict;
 use warnings;
-our $VERSION = '0.002001';
+our $VERSION = '0.002002';
 $VERSION =~ tr/_//d;
 
 use Moo::_Utils qw(_install_modifier);
@@ -16,10 +16,11 @@ sub import {
   }
 
   _install_modifier($target, 'before', ['has', 'extends', 'with'], sub {
-    Moo::Role->apply_roles_to_object(
-      Moo->_accessor_maker_for($target),
-      'MooX::TypeTiny::Role::GenerateAccessor',
-    );
+    my $am = Moo->_accessor_maker_for($target);
+    if (!$am->DOES('MooX::TypeTiny::Role::GenerateAccessor')) {
+      Moo::Role->apply_roles_to_object(
+        $am, 'MooX::TypeTiny::Role::GenerateAccessor' );
+    }
 
     # make sure we have our own constructor
     Moo->_constructor_maker_for($target);
